==> haskell-byte-order-0.1.3.1-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byte-order.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 byte-order
version:              0.1.3.1
visibility:           public
id:                   byte-order-0.1.3.1-8eLQe37m6mA7wzjUpiKwmT
key:                  byte-order-0.1.3.1-8eLQe37m6mA7wzjUpiKwmT
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           amartin@layer3com.com
author:               Andrew Martin
homepage:             https://github.com/byteverse/byte-order
synopsis:             Portable big-endian and little-endian conversions
description:
    This library provides an interface to portably work with byte
    arrays whose contents are known to be of a fixed endianness.
    There are two ways to use this module. See the `System.ByteOrder`
    module for more documentation.

category:             Data
abi:                  36057d0bef53bb3d1ade0a29883aaaa4
exposed:              True
exposed-modules:
    Data.Primitive.ByteArray.BigEndian
    Data.Primitive.ByteArray.LittleEndian Data.Primitive.Ptr.BigEndian
    System.ByteOrder System.ByteOrder.Class

import-dirs:          /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byte-order
hs-libraries:         HSbyte-order-0.1.3.1-8eLQe37m6mA7wzjUpiKwmT
depends:
    base-4.17.2.1 primitive-0.7.4.0-GWGNy3IYYzTHqwC4kY0YCL
    primitive-unaligned-0.1.1.2-9DXJvRd26NhE5xEw2kXLMp
    wide-word-0.1.7.0-CsDjtRmaVbEEWMReicAkU3

haddock-interfaces:   /usr/share/doc/haskell-byte-order/html/byte-order.haddock
haddock-html:         /usr/share/doc/haskell-byte-order/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-byte-order-0.1.3.1-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-byte-order.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 byte-order
version:              0.1.3.1
visibility:           public
id:                   byte-order-0.1.3.1-7LJeiU7Pt4wGzzGjhNQtzV
key:                  byte-order-0.1.3.1-7LJeiU7Pt4wGzzGjhNQtzV
license:              BSD-3-Clause
copyright:            2019 Andrew Martin
maintainer:           amartin@layer3com.com
author:               Andrew Martin
homepage:             https://github.com/byteverse/byte-order
synopsis:             Portable big-endian and little-endian conversions
description:
    This library provides an interface to portably work with byte
    arrays whose contents are known to be of a fixed endianness.
    There are two ways to use this module. See the `System.ByteOrder`
    module for more documentation.

category:             Data
abi:                  a2e5bb0208dbf9dfe15d40aa1a1bbc93
exposed:              True
exposed-modules:
    Data.Primitive.ByteArray.BigEndian
    Data.Primitive.ByteArray.LittleEndian Data.Primitive.Ptr.BigEndian
    System.ByteOrder System.ByteOrder.Class

import-dirs:          /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/byte-order-0.1.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-byte-order
hs-libraries:         HSbyte-order-0.1.3.1-7LJeiU7Pt4wGzzGjhNQtzV
depends:
    base-4.17.2.1 primitive-0.7.4.0-K4IT7bUBj0c2CIJh0yt8eH
    primitive-unaligned-0.1.1.2-9WaAAJ0N4BV5xzdieWFxj4
    wide-word-0.1.7.0-B7nQQfPcTRODGNua0oirUY

haddock-interfaces:   /usr/share/doc/haskell-byte-order/html/byte-order.haddock
haddock-html:         /usr/share/doc/haskell-byte-order/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
